<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="pl_PL" sourcelanguage="">
<context>
    <name>LogPassDialog</name>
    <message>
        <location filename="retext.py" line="175"/>
        <source>Enter your Google account data</source>
        <translation>Wprowadź dane twojego konta Google</translation>
    </message>
    <message>
        <location filename="retext.py" line="184"/>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <location filename="retext.py" line="185"/>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="retext.py" line="245"/>
        <source>File toolbar</source>
        <translation>Pasek pliku</translation>
    </message>
    <message>
        <location filename="retext.py" line="247"/>
        <source>Edit toolbar</source>
        <translation>Pasek edycji</translation>
    </message>
    <message>
        <location filename="retext.py" line="249"/>
        <source>Search toolbar</source>
        <translation>Pasek wyszukiwania</translation>
    </message>
    <message>
        <location filename="retext.py" line="251"/>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <location filename="retext.py" line="253"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location filename="retext.py" line="255"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="retext.py" line="258"/>
        <source>Save as</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <location filename="retext.py" line="260"/>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <location filename="retext.py" line="262"/>
        <source>Print preview</source>
        <translation>Podgląd wydruku</translation>
    </message>
    <message>
        <location filename="retext.py" line="264"/>
        <source>View HTML code</source>
        <translation>Zobacz źródło HTML</translation>
    </message>
    <message>
        <location filename="retext.py" line="265"/>
        <source>Change default font</source>
        <translation>Zmień domyślną czcionkę</translation>
    </message>
    <message>
        <location filename="retext.py" line="266"/>
        <source>Find text</source>
        <translation>Znajdź tekst</translation>
    </message>
    <message>
        <location filename="retext.py" line="270"/>
        <source>Preview</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <location filename="retext.py" line="279"/>
        <source>Live preview</source>
        <translation>Podgląd na żywo</translation>
    </message>
    <message>
        <location filename="retext.py" line="281"/>
        <source>Fullscreen mode</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <location filename="retext.py" line="288"/>
        <source>Other formats</source>
        <translation>Inne formaty</translation>
    </message>
    <message>
        <location filename="retext.py" line="294"/>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <location filename="retext.py" line="297"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="retext.py" line="299"/>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <location filename="retext.py" line="301"/>
        <source>Copy</source>
        <translation>Skopiuj</translation>
    </message>
    <message>
        <location filename="retext.py" line="303"/>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <location filename="retext.py" line="305"/>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <location filename="retext.py" line="315"/>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <location filename="retext.py" line="316"/>
        <source>Set locale</source>
        <translation>Ustaw język</translation>
    </message>
    <message>
        <location filename="retext.py" line="325"/>
        <source>Plain text</source>
        <translation>Tryb tekstowy</translation>
    </message>
    <message>
        <location filename="retext.py" line="327"/>
        <source>Use WebKit renderer</source>
        <translation>Używaj silnika WebKit</translation>
    </message>
    <message>
        <location filename="retext.py" line="334"/>
        <source>Generate webpages</source>
        <translation>Generuj stronę internetową</translation>
    </message>
    <message>
        <location filename="retext.py" line="335"/>
        <source>Show</source>
        <translation>Pokaż</translation>
    </message>
    <message>
        <location filename="retext.py" line="336"/>
        <source>Next</source>
        <translation>Następny</translation>
    </message>
    <message>
        <location filename="retext.py" line="337"/>
        <source>Previous</source>
        <translation>Poprzedni</translation>
    </message>
    <message>
        <location filename="retext.py" line="339"/>
        <source>Get help online</source>
        <translation>Pomoc online</translation>
    </message>
    <message>
        <location filename="retext.py" line="344"/>
        <source>About %s</source>
        <translation>O %s</translation>
    </message>
    <message>
        <location filename="retext.py" line="347"/>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <location filename="retext.py" line="368"/>
        <source>Bold</source>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <location filename="retext.py" line="369"/>
        <source>Italic</source>
        <translation>Kursywa</translation>
    </message>
    <message>
        <location filename="retext.py" line="370"/>
        <source>Underline</source>
        <translation>Podkreślenie</translation>
    </message>
    <message>
        <location filename="retext.py" line="373"/>
        <source>Save to Google Docs</source>
        <translation>Zapisz w Google Docs</translation>
    </message>
    <message>
        <location filename="retext.py" line="380"/>
        <source>Tags</source>
        <translation>Tagi</translation>
    </message>
    <message>
        <location filename="retext.py" line="384"/>
        <source>Symbols</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location filename="retext.py" line="408"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location filename="retext.py" line="409"/>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <location filename="retext.py" line="410"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="retext.py" line="413"/>
        <source>Open recent</source>
        <translation>Otwórz ostatnie</translation>
    </message>
    <message>
        <location filename="retext.py" line="416"/>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <location filename="retext.py" line="424"/>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
    <message>
        <location filename="retext.py" line="450"/>
        <source>Spell check</source>
        <translation>Sprawdzanie pisowni</translation>
    </message>
    <message>
        <location filename="retext.py" line="458"/>
        <source>Default editing mode</source>
        <translation>Domyślna metoda edycji</translation>
    </message>
    <message>
        <location filename="retext.py" line="461"/>
        <source>Formatting</source>
        <translation>Formatowanie</translation>
    </message>
    <message>
        <location filename="retext.py" line="499"/>
        <source>Search</source>
        <translation>Wyszukaj</translation>
    </message>
    <message>
        <location filename="retext.py" line="503"/>
        <source>Case sensitively</source>
        <translation>Rozróżnianie wielkości znaków</translation>
    </message>
    <message>
        <location filename="retext.py" line="1330"/>
        <source>New document</source>
        <translation>Nowy dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>You have neither Markdown nor Docutils modules installed!</source>
        <translation>Nie masz zainstalowanego modułu Markdown ani Docutils!</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>Only HTML formatting will be available.</source>
        <translation>Dostępne będzie tylko formatowanie HTML.</translation>
    </message>
    <message>
        <location filename="retext.py" line="726"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Wprowadź kod lokalizacji (np. en_US)</translation>
    </message>
    <message>
        <location filename="retext.py" line="813"/>
        <source>Please, save the file somewhere.</source>
        <translation>Proszę najpierw zapisać plik.</translation>
    </message>
    <message>
        <location filename="retext.py" line="800"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Strony internetowe zapisywane są w katalogu &lt;code&gt;html&lt;/code&gt;.</translation>
    </message>
    <message>
        <location filename="retext.py" line="802"/>
        <source>Show directory</source>
        <translation>Pokaż katalog</translation>
    </message>
    <message>
        <location filename="retext.py" line="807"/>
        <source>Webpages generator is not installed!</source>
        <translation>Generator stron internetowych nie jest zainstalowany!</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>Select one or several files to open</source>
        <translation>Zaznacz jeden lub więcej plików do otwarcia</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>Supported files</source>
        <translation>Obsługiwane pliki</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>All files (*)</source>
        <translation>Wszystkie pliki (*)</translation>
    </message>
    <message>
        <location filename="retext.py" line="984"/>
        <source>Plain text (*.txt)</source>
        <translation>Zwykły tekst (*.txt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="987"/>
        <source>ReStructuredText files</source>
        <translation>Pliki ReStructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="990"/>
        <source>HTML files</source>
        <translation>Pliki HTML</translation>
    </message>
    <message>
        <location filename="retext.py" line="993"/>
        <source>Markdown files</source>
        <translation>Pliki Markdown</translation>
    </message>
    <message>
        <location filename="retext.py" line="1071"/>
        <source>Save file</source>
        <translation>Zapisz plik</translation>
    </message>
    <message>
        <location filename="retext.py" line="1008"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Nie można zapisać pliku, ponieważ jest on tylko do odczytu!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1062"/>
        <source>Export document to ODT</source>
        <translation>Eksportuj do ODT</translation>
    </message>
    <message>
        <location filename="retext.py" line="1062"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Dokumenty OpenDokument (*.odt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1071"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Pliki HTML (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>Export document to PDF</source>
        <translation>Eksportuj do PDF</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>PDF files (*.pdf)</source>
        <translation>Pliki PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1109"/>
        <source>Print document</source>
        <translation>Drukuj dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="1128"/>
        <source>Export document</source>
        <translation>Eksportuj dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="1151"/>
        <source>Failed to execute the command:</source>
        <translation>Błąd podczas wykonywania komendy:</translation>
    </message>
    <message>
        <location filename="retext.py" line="1158"/>
        <source>This function is not available in Plain text mode!</source>
        <translation>Ta funkcja nie jest dostępna w trybie tekstowym!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1161"/>
        <source>Select type</source>
        <translation>Wybierz typ</translation>
    </message>
    <message>
        <location filename="retext.py" line="1224"/>
        <source>Incorrect user name or password!</source>
        <translation>Nieprawidłowa nazwa użytkownika lub hasło!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1227"/>
        <source>Authentification failed, please check your internet connection!</source>
        <translation>Logowanie nie powiodło się. Sprawdź połączenie internetowe!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1299"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokument został zmieniony.
Czy chcesz zapisać zmiany?</translation>
    </message>
    <message>
        <location filename="retext.py" line="1337"/>
        <source>HTML code</source>
        <translation>Kod HTML</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Simple but powerful editor for Markdown and ReStructuredText</source>
        <translation>Prosty, ale potężny edytor Markdown i RestructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011&lt;br&gt;
Tłumaczenie: Kristian Kann, 2012</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Website</source>
        <translation>Strona internetowa</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Markdown syntax</source>
        <translation>Składnia Markdown</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>ReST syntax</source>
        <translation>Składnia ReST</translation>
    </message>
    <message>
        <location filename="retext.py" line="1411"/>
        <source>Could not parse file contents, check if you have the necessary module installed!</source>
        <translation>Nie można wykonać zawartości pliku. Sprawdź, czy masz zainstalowane potrzebne moduły!</translation>
    </message>
</context>
</TS>
